==> 2.0.3.tar.gz: nci2/README.md <==
nci2: a simple blog manager and static site generator for neocities
===================================================================

![Language: Python](https://img.shields.io/static/v1?label=language&message=Python&color=yellow)
![License: Unlicense](https://img.shields.io/static/v1?label=license&message=Unlicense&color=lightgrey)

## ![Neocities](https://neocities.org/img/cat.png) ![nci2](https://codeberg.org/nokoru/nci2/raw/branch/master/nci2.png)

nci2 is a CLI app and blog/site generator and manager for neocities users. nci2
is an improved version of the original command line [nci webscript](https://notabug.org/nokoru/nci) by [nokoru](https://nokoru.neocities.org/). It was completely rewritten in python and it's now nci2!

nci2 lets you post, edit and delete blog entries without editing the HTML code of your blog. It makes managing your blog easier and faster.

How nci2 works
--------------
nci2 is pretty similar to the old webscript, except that now nci is actually installed on your system. The way nci and nci2 work is mainly inspired by the way the version control system software git works. You create an specific (local) directory for your website, and then you init the nci2 system inside of it, so you can easily manage your blog from your computer and you can upload it to neocities whenever you want to.

Why nci2
--------
It lets you manage your neocities blog easily, and it's fun to use if you like using the terminal (GNU/Linux, BSD and MacOS).

Installation
------------
Installing nci2 is relatively easy since most unix-like systems come with python pre-installed, however you should know the dependencies before installing this software.

#### Dependencies
* python 3+
* python 3 pip
* pip markdown module for python 3

#### Optional software
* git

#### Installation steps
1. Download this repository as a [zip file](https://codeberg.org/nokoru/nci2/archive/2.0.3.zip) or [tarball](https://codeberg.org/nokoru/nci2/archive/2.0.3.tar.gz). If you have git installed, you can run the following command to clone the repo: ```git clone https://codeberg.org/nokoru/nci2```
2. Once you cloned the nci2 repository, install it by selecting the directory where the nci2 system is in (```cd nci2```) and run ```./install``` to install nci2.
3. Wait for the installation to be completed. If the there are missing dependencies, the script will try to install them, however, keep in mind that this auto-installation of dependencies only works on some systems (Ubuntu, Mint, Debian-based distros, ...)
4. Run ```nci about``` to check whether nci2 was successfully installed or not.

#### nci2 wasn't installed?
Please install the dependencies to use nci2. Assuming that only the markdown module is missing, run ```pip3 install markdown``` to install it.

Installing nci2 on Windows
--------------------------
I don't know if nci2 may work on Windows. If you can make it work properly on Windows, please tell me and I'll add the steps to install nci2 on Windows. You can also submit a pull request.

Getting Started
---------------
1. Create a directory for your blog and select it. Example: ```mkdir my_neocities_blog && cd my_neocities_blog```
2. Run ```nci init```
3. Answer a few questions that nci will ask you in order to work properly
4. Congratulations! You just initialized nci2 in the directory of your website!

For more information about how to use this CLI app, run ```nci help``` or read the [nci2 wiki](https://codeberg.org/nokoru/nci2/wiki).

#### I already have a website and I don't want to lose my files
1. Follow all the steps above.
2. Run ```nci pull``` to download your website files from neocities.

Disclaimer
----------
nci2 is a hobby project made by me (nokoru). I won't be responsible for damages to your website caused by the misuse of this app.

Donations
---------
![donation cat](https://neocities.org/img/support-us.png)

Please [donate to neocities](https://neocities.org/donate) if you can. It's a lovely project. ❤️

Credits & License crap
----------------------
Original nci2 by [nokoru](https://nokoru.neocities.org/) <[nokoru@disroot.org](mailto:nokoru@disroot.org)> (chat/xmpp and e-mail)

nci2 is public domain software (license: Unlicense), so do whatever you want with it. Use it and adapt it to your needs. It'd be nice if you shared your modifications with other users, so everyone benefits :3

==> 2.0.5.tar.gz: nci2/README.md <==
nci2: a simple blog manager and static site generator for neocities
===================================================================

![Language: Python](https://img.shields.io/static/v1?label=language&message=Python&color=yellow)
![License: Unlicense](https://img.shields.io/static/v1?label=license&message=Unlicense&color=lightgrey)

## ![Neocities](https://neocities.org/img/cat.png) ![nci2](https://codeberg.org/nokoru/nci2/raw/branch/master/nci2.png)

nci2 is a CLI app and blog/site generator and manager for neocities users. nci2
is an improved version of the original command line [nci webscript](https://notabug.org/nokoru/nci) by [nokoru](https://nokoru.neocities.org/). It was completely rewritten in python and it's now nci2!

nci2 lets you post, edit and delete blog entries without editing the HTML code of your blog. It makes managing your blog easier and faster.

How nci2 works
--------------
nci2 is pretty similar to the old webscript, except that now nci is actually installed on your system. The way nci and nci2 work is mainly inspired by the way the version control system software git works. You create an specific (local) directory for your website, and then you init the nci2 system inside of it, so you can easily manage your blog from your computer and you can upload it to neocities whenever you want to.

Why nci2
--------
It lets you manage your neocities blog easily, and it's fun to use if you like using the terminal (GNU/Linux, BSD and MacOS).

Installation
------------
Installing nci2 is relatively easy since most unix-like systems come with python pre-installed, however you should know the dependencies before installing this software.

#### Dependencies
* python 3+
* python 3 pip
* pip markdown module for python 3

#### Optional software
* git

#### Installation steps
1. Download this repository as a [zip file](https://codeberg.org/nokoru/nci2/archive/2.0.5.zip) or [tarball](https://codeberg.org/nokoru/nci2/archive/2.0.5.tar.gz). If you have git installed, you can run the following command to clone the repo: ```git clone https://codeberg.org/nokoru/nci2```
2. Once you cloned the nci2 repository, install it by selecting the directory where the nci2 system is in (```cd nci2```) and run ```./install``` to install nci2.
3. Wait for the installation to be completed. If the there are missing dependencies, the script will try to install them, however, keep in mind that this auto-installation of dependencies only works on some systems (Ubuntu, Mint, Debian-based distros, ...)
4. Run ```nci about``` to check whether nci2 was successfully installed or not.

#### nci2 wasn't installed?
Please install the dependencies to use nci2. Assuming that only the markdown module is missing, run ```pip3 install markdown``` to install it.

If you can't run the `install` script, run `chmod +x install` to make the script executable, then run `./install` and
there shouldn't be any problems.

If you still can't install nci2, please [open an issue](https://codeberg.org/nokoru/nci2/issues) to get help.

Installing nci2 on Windows
--------------------------
I don't know if nci2 may work on Windows. If you can make it work properly on Windows, please tell me and I'll add the steps to install nci2 on Windows. You can also submit a pull request.

Getting Started
---------------
1. Create a directory for your blog and select it. Example: ```mkdir my_neocities_blog && cd my_neocities_blog```
2. Run ```nci init```
3. Answer a few questions that nci will ask you in order to work properly
4. Congratulations! You just initialized nci2 in the directory of your website!

For more information about how to use this CLI app, run ```nci help``` or read the [nci2 wiki](https://codeberg.org/nokoru/nci2/wiki).

#### I already have a website and I don't want to lose my files
1. Follow all the steps above.
2. Run ```nci pull``` to download your website files from neocities.

Disclaimer
----------
nci2 is a hobby project made by me (nokoru). I won't be responsible for damages to your website caused by the misuse of this app.

Donations
---------
![donation cat](https://neocities.org/img/support-us.png)

Please [donate to neocities](https://neocities.org/donate) if you can. It's a wonderful project. ❤️

Credits & License crap
----------------------
Original nci2 by [nokoru](https://nokoru.neocities.org/) <[nokoru@disroot.org](mailto:nokoru@disroot.org)> (chat/xmpp and e-mail)

nci2 is public domain software (license: Unlicense), so do whatever you want with it. Use it and adapt it to your needs. It'd be nice if you shared your modifications with other users, so everyone benefits :3
